@@ -1,16 +1,19 @@
 use crate::security::*;
 
-#[cfg(feature="extended-handler")]
+#[cfg(feature = "extended-handler")]
 use crate::types::application::*;
 
-#[cfg(feature="handler")]
+#[cfg(feature = "handler")]
 use crate::types::interaction::*;
 
-#[cfg(feature="extended-handler")]
+#[cfg(feature = "extended-handler")]
 use crate::types::HttpError;
 use crate::types::Snowflake;
-#[cfg(feature="extended-handler")]
-use crate::{expect_specific_api_response, expect_successful_api_response_and_return};
+#[cfg(feature = "extended-handler")]
+use crate::{
+    expect_specific_api_response, expect_successful_api_response,
+    expect_successful_api_response_and_return,
+};
 use actix_web::http::StatusCode;
 use actix_web::{web, App, HttpRequest, HttpResponse, HttpServer, Result};
 use reqwest::header;
@@ -19,12 +22,16 @@ use reqwest::Client;
 use log::{debug, error};
 use std::fmt;
 
+use anymap::{any::CloneAny, Map};
+
 use ed25519_dalek::PublicKey;
 
 use rustls::ServerConfig;
 
 use std::{collections::HashMap, future::Future, pin::Pin, sync::Mutex};
 
+type AnyMap = Map<dyn CloneAny + Send + Sync>;
+
 /// Alias for InteractionResponse
 pub type HandlerResponse = InteractionResponse;
 
@@ -86,6 +93,9 @@ pub struct InteractionHandler {
 
     // These handles are 'forgotten' every time the app is shutdown (whatever the reason may be).
     guild_handles: HashMap<Snowflake, HandlerFunction>,
+
+    /// Field to access data
+    pub data: AnyMap,
 }
 
 #[cfg(feature = "handler")]
@@ -121,10 +131,10 @@ impl InteractionHandler {
             // Let it panic if there is no valid value
             let auth_value = header::HeaderValue::from_str(token.as_str());
 
-            if auth_value.is_err(){
+            if auth_value.is_err() {
                 panic!("Invalid value given at token");
             }
-            
+
             let mut auth_value = auth_value.unwrap();
 
             auth_value.set_sensitive(true);
@@ -138,6 +148,7 @@ impl InteractionHandler {
                 global_handles: HashMap::new(),
                 component_handles: HashMap::new(),
                 guild_handles: HashMap::new(),
+                data: AnyMap::new(),
             }
         } else {
             InteractionHandler {
@@ -147,10 +158,18 @@ impl InteractionHandler {
                 global_handles: HashMap::new(),
                 component_handles: HashMap::new(),
                 guild_handles: HashMap::new(),
+                data: AnyMap::new(),
             }
         }
     }
 
+    /// Add some data. Data can be accessed by handlers with `InteractionHandler.data`
+    pub fn add_data<T: Clone>(&mut self, data: T)
+    where
+        T: Send + 'static + Sync,
+    {
+        self.data.insert(data);
+    }
     /// Binds an async function to a **global** command.
     /// Your function must take a [`Context`] as an argument and must return a [`InteractionResponse`].
     /// Make sure to use the `#[slash_command]` procedural macro to make it usable for the handler.
@@ -349,6 +368,48 @@ impl InteractionHandler {
         }
     }
 
+    #[cfg(feature = "extended-handler")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "extended-handler")))]
+    /// Override a bunch of permissions for commands in a guild.
+    pub async fn override_guild_permissions(
+        &self,
+        guild_id: impl Into<Snowflake>,
+        overrides: &[ApplicationCommandPermissionBatch],
+    ) -> Result<(), HttpError> {
+        let url = format!(
+            "{}/applications/{}/guilds/{}/commands/permissions",
+            crate::BASE_URL,
+            self.application_id,
+            guild_id.into()
+        );
+
+        let res = self.client.put(&url).json(overrides).send().await;
+
+        expect_successful_api_response!(res, Ok(()))
+    }
+
+    #[cfg(feature = "extended-handler")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "extended-handler")))]
+    /// Add a permission override for a guild command
+    pub async fn edit_guild_command_permissions(
+        &self,
+        guild_id: impl Into<Snowflake>,
+        appcmd_id: impl Into<Snowflake>,
+        permission_override: &ApplicationCommandPermission,
+    ) -> Result<(), HttpError> {
+        let url = format!(
+            "{}/applications/{}/guilds/{}/commands/{}/permissions",
+            crate::BASE_URL,
+            self.application_id,
+            guild_id.into(),
+            appcmd_id.into(),
+        );
+
+        let res = self.client.put(&url).json(permission_override).send().await;
+
+        expect_successful_api_response!(res, Ok(()))
+    }
+
     /// Entry point function for handling `Interactions`
     pub async fn interaction(&mut self, req: HttpRequest, body: String) -> Result<HttpResponse> {
         // Check for good content type --> must be application/json
