@@ -13,6 +13,9 @@ pub mod interaction;
 /// Module containing structures for members/users.
 pub mod user;
 
+/// Module containing structures for using [Message Components](https://discord.com/developers/docs/interactions/message-components#what-are-components)
+pub mod components;
+
 /// Module containing structures for guilds
 pub mod guild;
 //use interaction::{InteractionResponse, Interaction};
